@@ -3,7 +3,7 @@ import sys
 import os 
 dir_path = os.path.dirname(os.path.realpath(__file__))
 sys.path.append(dir_path+"/..")
-from githubToolsUcll import service
+from githubToolsUCLL import service
 
 
 # de student pullt alle issues van de hoofd-repo na het clonen van de start-code
